/*
 * @Description: 检验项目相关
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-06-26 03:07:40
 */

import { Ref, h, unref } from 'vue';
import { DeleteEntity, GetEnum, getEntity } from '/@/api/tigerapi/system';
import { ActionItem, BasicColumn } from '/@/components/Table';
import { isNullOrEmpty, isNullOrUnDef } from '/@/utils/is';
import { buildUUID } from '/@/utils/uuid';
import { useUserStore } from '/@/store/modules/user';
import { formatToDateTime } from '/@/utils/dateUtil';
import { Tag } from 'ant-design-vue';
import { useLocale } from '/@/locales/useLocale';

const { getLocale } = useLocale();
function _default() {
  const ActionColumn: BasicColumn = {
    width: 80,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: undefined,
  };

  const methods = {
    EditOperation: ( data: Ref<any[]>, d, u) => {
      if (u.isUpdate) {
        //更新
        var _data = data.value.map((item) => {
          if (item['ID'] == d.ID)
            return {
              ...item,
              STD_CODE: d.STD_CODE,
              STD_NAME: d.STD_NAME,
              STD_TYPE: d.STD_TYPE,
              REMARK: d.REMARK,
            };
          return item;
        });
        data.value = _data;
      } else {
        //新增
        d.ID = buildUUID();
        d.CREATE_USER = useUserStore().getUserInfo.userId as string;
        d.UPDATE_TIME = formatToDateTime(new Date());
        d.UPDATE_USER = useUserStore().getUserInfo.userId as string;
        var _data2: any[] = [];
        if (!isNullOrEmpty(data.value)) {
          _data2 = data.value.map((item) => {
            return item;
          });
        }
        _data2.push(d);
        data.value = _data2;
      }
    },
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (fnName: string) => {
      return {
        action: 'drawer', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
      };
    },
    /**
     * @description: 操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      if (!isNullOrUnDef(data[1])) {
        data[1].popConfirm.confirm = Del.bind(null, args, params);
    }
      return data;
    },
    /**
     * @description: 高级表单和详情页面返回主页面的url
     * @return {*}
     */  
    GetHomeUrl: () => {
      const param = { ID: 'QMS_INS_STD', colSlots: [], crudColSlots: [] };
      return `/QMS_INS_STD/LC/${encodeURI(JSON.stringify(param))}`;
    },
    GetBaseColumns: () => {
      return [
        {
          title: '检验项目编码',
          dataIndex: 'INS_CODE',
          // ifShow: false,
          width: 180,
        },
        {
          title: '检验项目名称',
          dataIndex: 'INS_NAME',
        },
        {
          title: '检验类别编码',
          dataIndex: 'CTGY_CODE',
        },
        {
          title: '检验方式',
          dataIndex: 'INS_MODE',
          customRender: ({ record }) => {
            const type = record.INS_MODE;
            var text = '';
            var color = 'green';
            switch (type) {
              case 0:
                text = '定量检测';
                break;
              case 1:
                color = 'blue';
                text = '定性检测';
                break;
            }
            return h(Tag, { color: color }, () => text);
          },
        },
        {
          title: '检验标准编码',
          dataIndex: 'TECH_STD',
        },
        {
          title: '是否必检',
          dataIndex: 'IS_NECESSARY',
          customRender: ({ record }) => {
            const type = record.IS_NECESSARY;
            var text = '';
            var color = 'green';
            switch (type) {
              case 'Y':
                text = '是';
                break;
              case 'N':
                color = 'blue';
                text = '否';
                break;
            }
            return h(Tag, { color: color }, () => text);
          },
        },
        {
          title: '是否判定结果',
          dataIndex: 'IS_JUDGE',
          customRender: ({ record }) => {
            const type = record.IS_JUDGE;
            var text = '';
            var color = 'green';
            switch (type) {
              case 'Y':
                text = '是';
                break;
              case 'N':
                color = 'blue';
                text = '否';
                break;
            }
            return h(Tag, { color: color }, () => text);
          },
        },
        {
          title: '检验工具',
          dataIndex: 'INS_TOOL',
        },
        {
          title: '测试值单位',
          dataIndex: 'QNTV_UNIT',
        },
        {
          title: '测试次数',
          dataIndex: 'QNTV_TIMES',
        },
        {
          title: '偏差值',
          dataIndex: 'QNTV_DEVIATION',
        },
        {
          title: '备注',
          dataIndex: 'REMARK',
        },
        {
          title: '更新时间',
          dataIndex: 'UPDATE_TIME',
        },
        {
          title: '更新人',
          dataIndex: 'UPDATE_USER',
        },
      ];
    },
    GetSearchForm: () => {
      return [
        {
          field: 'INS_CODE',
          label: '检验项目编码',
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '检验项目名称',
          field: 'INS_NAME',
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
      ];
    },
    GetCrudForm: () => {
      return [
        {
          field: 'INS_CODE',
          label: '检验项目编码',
          component: 'Input',
          required: true,
          colProps: {
            span: 24,
          },
        },
        {
          label: '检验项目名称',
          field: 'INS_NAME',
          component: 'Input',
          required: true,
          colProps: {
            span: 24,
          },
        },
        {
          label: '检验类别编码',
          field: 'CTGY_CODE',
          component: 'Input',
          colProps: {
            span: 24,
          },
        },
        {
          label: '检验标准',
          field: 'TECH_STD',
          component: 'ApiSelect',
          colProps: {
            span: 24,
          },
          componentProps: {
            api: getEntity,
            params: { entityName: 'QMS_INS_STD', sqlcmd: ' 1=1 ' },
            resultField: 'Data.Items',
            labelField: 'STD_NAME',
            valueField: 'STD_CODE',
          },
          dynamicDisabled: ({ values }) => {
            return true;
          },
        },
        {
          label: '检验方式',
          field: 'INS_MODE',
          component: 'ApiSelect',
          required: true,
          colProps: {
            span: 24,
          },
          componentProps: {
            api: GetEnum,
            params: { name: 'QMS_INS_ITEM+INS_MODEs' },
            resultField: 'Data',
            labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
            valueField: 'Value',
          },
        },
        {
          label: '备注',
          field: 'REMARK',
          component: 'Input',
          colProps: {
            span: 24,
          },
        },
        {
          label: 'ID',
          field: 'ID',
          component: 'Input',
          colProps: {
            span: 24,
          },
          show: false,
        },
      ];
    },
    GetBaseForm: () => {
      return [
        {
          field: 'STD_CODE',
          label: '检验标准编码',
          component: 'Input',
          required: true,
          colProps: {
            span: 8,
          },
        },
        {
          label: '检验标准名称',
          field: 'STD_NAME',
          required: true,
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '备注',
          field: 'REMARK',
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: 'ID',
          field: 'ID',
          component: 'Input',
          colProps: {
            span: 8,
          },
          show: false,
        },
        {
          label: 'TECH_STD',
          field: 'TECH_STD',
          component: 'Input',
          colProps: {
            span: 8,
          },
          show: false,
        },
      ];
    },
    GetBaseCards: () => {
      return [
        {
          name: 'BaseForm',
          slots: [],
          preIcons: {},
          title: '检验标准',
          entityName: 'QMS_INS_STD',
        },
        // {
        //   name: 'prodinfo',
        //   slots: ['addRot', 'setRot'],
        //   preIcons: { addRot: 'search|svg', setRot: 'config|svg' },
        //   title: '产品信息',
        // },
        // { name: 'rotinfo', slots: ['add'], preIcons: { add: 'search|svg' }, title: '工艺信息' },
      ];
    },
    OthersValues: (val: string, id: string) => {
      return { TECH_STD: val };
    },
    /**
     * @description: 获取标题信息
     * @param {string} type
     * @return {*}
     */
    GetTitle: () => {
      return {
        pageTitle: '检验标准管理',
        pageContent: '这里可以添加和修改检验标准和检验项目。',
        baseTableTitle: '检验项目管理',
      };
    },
  };

  /**
   * @description: 自定义删除方法
   * @param {Fn} args
   * @param {*} params
   * @return {*}
   */
  function Del(args: Fn[], params: {}) {
    if (!isNullOrEmpty(params['data'])) {
      var _data = params['data'].value.filter((item) => item['ID'] != params['record']['ID']);
      params['data'].value = _data;
      args[6]({
        dataSource: [],
      });
      args[6]({
        dataSource: params['data'],
      });
      args[1]();
    } else {
      DeleteEntity(params['record'], params['entityName']).then((action) => {
        if (action.IsSuccessed) {
          args[1]();
        }
      });
    }
  }

  return [methods, ActionColumn];
}

export default _default;
